# "uname -r" output of the kernel to build for, the running one
# if none was specified with "--define 'kernel <uname -r>'"
%{!?kernel: %{expand: %%define kernel %(uname -r)}}

%define kversion %(echo %{kernel} | sed -e s/xen// -)
%define krelver  %(echo %{kversion} | tr -s '-' '_')
%define kmach %(echo %{kernel} | perl -ne 'print "-$1" if /%{_target_cpu}\.(.+)/')

%if %(echo %{kernel} | grep -c xen)
        %{expand:%%define kxensufix -xen}
%endif

%define dahdiuserver 2.10.0.1

# % define rcver 2

# Need to unset this in order to prevent build failures in Fedora 17
%define __global_ldflags %{nil}

Summary: Telephony interface support
Name: dahdi
Version: 2.10.0.1
Release: 3%{?rcver:.rc%{rcver}}%{?dist}
License: GPL
Group: System Environment/Libraries
URL: http://www.asterisk.org/
Source0: http://downloads.asterisk.org/pub/telephony/dahdi-linux-complete/dahdi-linux-complete-%{version}%{?rcver:-rc%{rcver}}+%{dahdiuserver}.tar.gz
Source1: dahdi-2.6.1-synway-firmware.tar.gz
Source2: http://updates.xorcom.com/astribank/hwec/OCT6104E-256D.ima
Source3: OCT6104E-256D-LICENSE.txt

# This adds support for Openvox digital and analog cards:
# opvxd115 opvxa1200 opvxa24xx
# It also adds hardware echo canceller and new PCI ids to: wcb4xxp wct4xxp
# This adds support for the HFC-S PCI A based ISDN BRI cards: zaphfc
# http://downloads.openvox.cn/pub/drivers/dahdi-linux-complete/releases/1.3.7/
Patch1:  dahdi-2.10.0.1-openvox-opvxd115-opvxa1200-opvxa24xx-zaphfc-1.3.7-v2.patch

# This adds support for Openvox GSM cards: opvxg4xx, plus chan_extra support
# http://www.chan-extra.org/download/chan_extra-2.0.7.tar.gz
Patch2:  dahdi-2.9.1.1-openvox-opvxg4xx-chan-extra-2.0.8-v2.patch

# This adds support for Yeastar TDM FXS/FXO: ystdm8xx ystdm16xx
# http://www.yeastar.com/download/dahdi/dahdi-linux-2.6.1/ystdm16xx.c
# http://www.yeastar.com/download/dahdi/dahdi-linux-2.6.1/ystdm8xx.c
Patch3:  dahdi-2.9.1.1-yeastar-ystdm8xx-ystdm16xx.patch

# This adds support for Aligera AP400: ap400
# https://git.gitorious.org/dahdi-extra/dahdi-linux-extra.git
Patch4:  dahdi-2.9.1.1-aligera-ap400.patch

# This adds support for the ATCOM AX1600P/800P cards: ax1600p
# (manually patched for dahdi-2.6.1)
Patch5:  dahdi-2.9.1.1-atcom-ax1600p.patch

# This adds support for Voicetronix: wcopenpci
# https://git.gitorious.org/dahdi-extra/dahdi-linux-extra.git
Patch7:  dahdi-2.9.1.1-voicetronix-wcopenpci.patch

# This sets default echo canceller to oslec
Patch8:  dahdi-2.8.0.1-set-default-echocan-oslec.patch

# This adds support for SYNWAY cards minus firmware: fxm32 tej21
# Malvin <cheny@sanhuid.com>, Alex Huang <alex.huang.cp@gmail.com>
# WJ@sanhuid.com, Zhang MingJun <zmj@sanhuid.com>
Patch9:  dahdi-2.9.1.1-synway-no-firmware-v2.patch

# This adds support for ALLO cards: allo4xxp
# ftp://allo_bri:cem*allo@61.12.17.162/allo4xxp-dahdi-2.6.1_EC.patch
Patch10: dahdi-2.10.0.1-allo-allo4xxp.patch

#Allo 2/4/8 port PRI cards support
Patch11: dahdi-2.10.0.1-allopri-allop4xxp-v2.patch


# This patch enables additional behavior for the wcte11xp driver based on wafer version
Patch20: dahdi-2.9.1.1-wcte11xp-version-behavior.patch

# Recognize BRI channels from Sangoma
Patch21: dahdi-2.9.1.1-recognize-sangoma-bri.patch

# Install version.h so that rhino/wanpipe drivers can compile correctly
Patch22: dahdi-2.9.1.1-also-install-version-h.patch

# Prevent tor2 driver from claiming Khomp devices
Patch23: dahdi-2.9.1.1-prevent-conflict-tor2-khomp.patch

# Add Kenya tonezone to dahdi
Patch24: dahdi-2.9.1.1-tonezone-kenya.patch

# Recognize and generate configuration for Sangoma GSM WAT
Patch25: dahdi-2.9.1.1-recognize-sangoma-wat.patch

# Prevent tor2 driver from claiming AlloGSM devices
Patch26: dahdi-2.9.1.1-prevent-conflict-tor2-allogsm.patch

# Wrap kernel parameters on zaphfc in CONFIG_PCI to fix build in ARM
Patch27: dahdi-2.9.1.1-zaphfc-wrap-params-config-pci.patch

# This adds support for ALLO cards: allog4c 
Patch28: dahdi-2.9.1.1-allo-allog4c-v5.patch

# Prevent Raspberry Pi macro definitions from colliding with opvxg4xx and allogsm driver
Patch29: dahdi-2.9.1.1-prevent-collision-raspberrypi-uart.patch

# Blacklist CentOS ISDN drivers that conflict with DAHDI
Patch30: dahdi-2.9.1.1-blacklist-foreign-drivers.patch

# Backwards compatibility for using udev 095 from CentOS 5 with DAHDI 2.9+
%if ! 0%{?fedora}
Patch31: dahdi-2.10.0.1-backcompat-udev-95.patch
%endif


BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
%if 0%{?fedora}%{?centos_ver}
BuildRequires: kernel%{?kxensufix}-devel-uname-r = %{kversion}
Requires(pre): perl
%else
BuildRequires: kernel%{?kxensufix}-devel = %{kversion}
Prereq: perl
%endif
BuildRequires: newt-devel, libusb-devel
Requires: which
Obsoletes: kernel-module-oslec
Obsoletes: kernel-module-oslec-xen
Obsoletes: oslec
Obsoletes: zaptel
Obsoletes: zaptel-devel
Obsoletes: kernel-module-zaptel
Obsoletes: kernel-module-zaptel-xen
Conflicts: asterisk <= 2009020507:1.6.2.13-0
Conflicts: kernel-module-wanpipe%{?kxensufix} <= 3.5.14-0_%{krelver}
Conflicts: kernel-module-rhino%{?kxensufix} <= 2:0.99.3-2.beta2_%{krelver}
Conflicts: dahdi-devel < %{version}
Conflicts: wanpipe-util <= 3.5.25

%description
This package contains the libraries, device entries, startup scripts and tools
needed to use Digium telephony hardware. This includes the pseudo TDM
interfaces.

You will also need to install a kernel modules package matching your current
kernel for everything to work, and edit /etc/modprobe.conf.


%package devel
Summary: Header files and development libraries for DAHDI
Group: Development/Libraries
Requires: %{name} = %{version}
Obsoletes: kernel-module-dahdi-devel

%description devel
This package contains the header files needed to compile applications that
will use DAHDI, such as Asterisk. It also contains header files to build
additional kernel modules that request source access to the dahdi kernel
files.

%package -n kmod-dahdi%{?kxensufix}%{?kmach}
Summary: Kernel modules required for some hardware to operate with Dahdi
Group: System Environment/Kernel
Requires: dahdi = %{version}-%{release}
%if 0%{?fedora}%{?centos_ver}
Requires(pre): module-init-tools
Requires(post): kernel-%{_target_cpu}
%else
Prereq: module-init-tools
Prereq: kernel-%{_target_cpu}
%endif
Obsoletes: kernel-module-dahdi-bri%{?kxensufix}
Obsoletes: kernel-module-dahdi%{?kxensufix}
Conflicts: asterisk <= 2009020507:1.6.2.13-0
Conflicts: kernel-module-wanpipe%{?kxensufix} <= 3.5.14-0_%{krelver}
Conflicts: kernel-module-rhino%{?kxensufix} <= 2:0.99.3-2.beta2_%{krelver}
Conflicts: kmod-wanpipe%{?kxensufix} <= 7.0.10-1
Conflicts: kmod-rhino%{?kxensufix} <= 2:0.99.6-2.b4

%description -n kmod-dahdi%{?kxensufix}%{?kmach}
This package contains the dahdi kernel modules for the Linux kernel package :
%{kversion} (%{_target_cpu}%{?kxensufix:, XEN}).

%prep

%if "%{?kmach}" != ""
echo -e "\n\nCOMPILING for arch %{_target_cpu}%{kmach}\n\n"
%endif

%setup -n dahdi-linux-complete-%{version}%{?rcver:-rc%{rcver}}+%{dahdiuserver}

# New driver support
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1

# Fixes to existing drivers and tools
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%if ! 0%{?fedora}
%patch31 -p1
%endif

# Unpack SYNWAY firmwares into expected locations
tar -xzf %{SOURCE1}

# Copy Xorcom firmwares into expected locations
cp %{SOURCE2} %{SOURCE3} linux/drivers/dahdi/xpp/firmwares/

%build
export CFLAGS="%{optflags}"

# The configure script must be run inside the tools directory BEFORE running
# make, otherwise the 'lib64' destination directory is not specified correctly 
# on x86_64. The makefile verifies the presence of config.status and skips its
# own configure command if present.
cd tools
%configure --with-dahdi=../linux
cd ..
%{__make} \
    KVERS="%{kernel}" \
    MODULES_EXTRA="ystdm8xx ystdm16xx ax1600p wcopenpci" \
    SUBDIRS_EXTRA="allog4c/ cem4xxp/ allop4xxp/ zaphfc/ ap400/ opvxd115/ opvxa1200/ opvxa24xx/ opvxg4xx/ tej21/ fxm32/" \
    PERLLIBDIR=%{perl_vendorlib}

%install
%{__rm} -rf %{buildroot}
# Install checks the presence of this file to decide which to modify
%{__mkdir_p} %{buildroot}%{_sysconfdir}/udev/rules.d
#touch %{buildroot}%{_sysconfdir}/modprobe.conf
# Required in 1.2.0
%{__mkdir_p} %{buildroot}%{_mandir}/man8

# Main install
%{__make} install \
    KVERS="%{kernel}" \
    DESTDIR="%{buildroot}" \
    MODULES_EXTRA="ystdm8xx ystdm16xx ax1600p wcopenpci" \
    SUBDIRS_EXTRA="allog4c/ cem4xxp/ allop4xxp/ zaphfc/ ap400/ opvxd115/ opvxa1200/ opvxa24xx/ opvxg4xx/ tej21/ fxm32/" \
    PERLLIBDIR=%{perl_vendorlib}

# Install SYNWAY firmware manually
cp linux/drivers/dahdi/fxm32/*.bin linux/drivers/dahdi/tej21/*.bin %{buildroot}/lib/firmware/
cp linux/drivers/dahdi/fxm32/*.bin linux/drivers/dahdi/tej21/*.bin %{buildroot}/usr/lib/hotplug/firmware/

# Install the init script
%{__install} -Dp -m0755 tools/dahdi.init %{buildroot}%{_sysconfdir}/rc.d/init.d/dahdi 

# Required now to install the config files
%{__make} config \
    KVERS="%{kernel}" \
    INSTALL_PREFIX="%{buildroot}" \
    DESTDIR="%{buildroot}" \
    ROOT_PREFIX="%{buildroot}" \
    MODULES_EXTRA="ystdm8xx ystdm16xx ax1600p wcopenpci" \
    SUBDIRS_EXTRA="allog4c/ cem4xxp/ allop4xxp/ zaphfc/ ap400/ opvxd115/ opvxa1200/ opvxa24xx/ opvxg4xx/ tej21/ fxm32/" \
    PERLLIBDIR=%{perl_vendorlib}

# Manually install xpp.conf (Elastix bug #371)
%{__install} linux/drivers/dahdi/xpp/xpp.conf %{buildroot}%{_sysconfdir}/dahdi/xpp.conf

# Manually install Module.symvers
%{__mkdir_p} %{buildroot}/usr/drivers/dahdi/
%{__install} linux/drivers/dahdi/Module.symvers %{buildroot}/usr/drivers/dahdi/Module.symvers

# The files here are not needed in CentOS
rm -rf %{buildroot}%{_sysconfdir}/hotplug

# Elastix provides its own /etc/dahdi/genconf_parameters. We rename this
# file to /etc/dahdi/genconf_parameters.sample to be used as a reference.
mv %{buildroot}%{_sysconfdir}/dahdi/genconf_parameters %{buildroot}%{_sysconfdir}/dahdi/genconf_parameters.sample

# Rename supplied /etc/dahdi/modules to /etc/dahdi/modules.sample
mv %{buildroot}%{_sysconfdir}/dahdi/modules %{buildroot}%{_sysconfdir}/dahdi/modules.sample
touch %{buildroot}%{_sysconfdir}/dahdi/modules

# Organize documentation
mkdir -p docs/tools docs/linux
cp ChangeLog README docs/
cp linux/LICENSE linux/LICENSE.LGPL linux/README linux/UPGRADE.txt docs/linux/
cp tools/LICENSE tools/LICENSE.LGPL tools/README tools/UPGRADE.txt docs/tools/

# Remove any modules.* found
rm -f %{buildroot}/lib/modules/%{kernel}/modules.*

# Collect all kernel modules in extra for weak-updates support
mkdir %{buildroot}/lib/modules/%{kernel}/extra
mv `find %{buildroot}/lib/modules/%{kernel}/dahdi/ -name *.ko` %{buildroot}/lib/modules/%{kernel}/extra/
rm -rf %{buildroot}/lib/modules/%{kernel}/dahdi/
ls %{buildroot}/lib/modules/%{kernel}/extra/*.ko | sed -ne 's:^%{buildroot}::p' > %{buildroot}/lib/modules/%{kernel}/extra/.kmod-dahdi-%{version}-%{release}

%clean
%{__rm} -rf %{buildroot}



%pre
# Por Alex Villacis Lasso - respaldos de configuracion previa de zapata/zaptel
if [ $1 -eq 1 ]; then
    # caso instalación
    echo -e "Looking for legacy zapata/zaptel configuration..."
    if [ -f /etc/zaptel.conf ]; then 
        mv /etc/zaptel.conf /etc/zaptel.conf.migrate.elastix
        rm -f /etc/zaptel.conf.rpmsave
    elif [ -f /etc/zaptel.conf.rpmsave ]; then
        mv /etc/zaptel.conf.rpmsave /etc/zaptel.conf.rpmsave.migrate.elastix
    fi

    if [ -f /etc/asterisk/zapata-channels.conf ]; then 
        mv /etc/asterisk/zapata-channels.conf /etc/asterisk/zapata-channels.conf.migrate.elastix
    fi
    if [ -f /etc/asterisk/zapata_additional.conf ]; then
        mv /etc/asterisk/zapata_additional.conf /etc/asterisk/zapata_additional.conf.migrate.elastix
    fi
fi


%post 
/sbin/ldconfig
/sbin/chkconfig --add dahdi
/sbin/chkconfig --level 2345 dahdi on
mkdir -p /var/lib/digium/licenses

######### Migrate zaptel to dahdi config ###############

# Por Alex Villacis Lasso - migrar configuracion previa de zapata/zaptel a dahdi
if [ $1 -eq 1 ]; then
    # caso instalacion 
    if [ -f /etc/zaptel.conf.migrate.elastix ] || [ -f /etc/zaptel.conf.rpmsave.migrate.elastix ]; then
        echo -e "Copying legacy zaptel.conf to /etc/dahdi/system.conf..."
        if [ -f /etc/zaptel.conf.rpmsave.migrate.elastix ]; then 
            cat /etc/zaptel.conf.rpmsave.migrate.elastix > /etc/dahdi/system.conf 
            mv /etc/zaptel.conf.rpmsave.migrate.elastix /etc/zaptel.conf.rpmsave.bck.elastix
        elif [ -f /etc/zaptel.conf.migrate.elastix ]; then
            cat /etc/zaptel.conf.migrate.elastix > /etc/dahdi/system.conf
            mv /etc/zaptel.conf.migrate.elastix /etc/zaptel.conf.bck.elastix
        fi
    fi
    if [ -f /etc/asterisk/zapata-channels.conf.migrate.elastix ]; then
        echo -e "Copying legacy zapata-channels.conf to /etc/asterisk/dahdi-channels.conf..."
        cat /etc/asterisk/zapata-channels.conf.migrate.elastix > /etc/asterisk/dahdi-channels.conf
        mv /etc/asterisk/zapata-channels.conf.migrate.elastix /etc/asterisk/zapata-channels.conf.bck.elastix
    fi
    if [ -f /etc/asterisk/zapata_additional.conf.migrate.elastix ]; then
        echo -e "Copying legacy zapata-additional.conf to /etc/asterisk/chan_dahdi_additional.conf..."
        cat /etc/asterisk/zapata_additional.conf.migrate.elastix > /etc/asterisk/chan_dahdi_additional.conf
        mv /etc/asterisk/zapata_additional.conf.migrate.elastix /etc/asterisk/zapata_additional.conf.bck.elastix
    fi
fi


touch /etc/fxotune.conf

# Blacklist modules provided by dahdi in order to control load order.
for i in opvxa1200 opvxd115 opvxa24xx opvxg4xx ystdm8xx ystdm16xx ap400 dahdi_dynamic_eth dahdi_dynamic_ethmf ax1600p zaphfc wcopenpci tej21 fxm32 cem4xxp allop4xxp tor2 allog4c; do
#    if ! grep -q $i /etc/dahdi/modules ; then
#        echo $i >> /etc/dahdi/modules
#    fi
    if ! grep -q $i /etc/modprobe.d/dahdi.blacklist.conf ; then
        echo "blacklist $i" >> /etc/modprobe.d/dahdi.blacklist.conf
    fi
done

# The following modules are part of the stock CentOS kernel, and grab PCI IDs 
# that are also handled by DAHDI. They should be blacklisted in order to 
# allow the dahdi driver to load.
for i in hisax hfc4s8s_l1 hfcmulti netjet hfcpci ; do
    if ! grep -q $i /etc/modprobe.d/dahdi.blacklist.conf ; then
        echo "blacklist $i" >> /etc/modprobe.d/dahdi.blacklist.conf
    fi
done

# Generate /etc/dahdi/modules file if empty
if [ ! -s /etc/dahdi/modules ] ; then
    echo "Scanning for supported devices..."
    /usr/sbin/dahdi_genconf modules
    echo -e "The following detected devices were written to /etc/dahdi/modules :\n"
    cat /etc/dahdi/modules
    echo -e "\nEnd of module list for detected devices."
fi

%postun 
/sbin/ldconfig

%post -n kmod-dahdi%{?kxensufix}%{?kmach}
if [ -e /boot/System.map-%{kernel} ] ; then
	/sbin/depmod -a -F /boot/System.map-%{kernel} %{kernel} &>/dev/null || :
fi
if [ -e /sbin/weak-modules ] ; then
	cat /lib/modules/%{kernel}/extra/.kmod-dahdi-%{version}-%{release} | /sbin/weak-modules --add-modules
else
	echo "WARN: /sbin/weak-modules not found, cannot associate with kernel updates!"
fi

%preun -n kmod-dahdi%{?kxensufix}%{?kmach}

# Run weak-module uninstall on uninstall only
if [ $1 -eq 0 ] ; then
    cp /lib/modules/%{kernel}/extra/.kmod-dahdi-%{version}-%{release} /tmp/
fi


%postun -n kmod-dahdi%{?kxensufix}%{?kmach}
if [ -e /boot/System.map-%{kernel} ] ; then
	/sbin/depmod -a -F /boot/System.map-%{kernel} %{kernel} &>/dev/null || :
fi

# Run weak-module uninstall on uninstall only
if [ $1 -eq 0 ] ; then
    if [ -e /sbin/weak-modules ] ; then
        cat /tmp/.kmod-dahdi-%{version}-%{release} | /sbin/weak-modules --remove-modules
    else
        echo "WARN: /sbin/weak-modules not found!"
    fi
    rm -f /tmp/.kmod-dahdi-%{version}-%{release}
fi

#%files -f device.list
%files
%defattr(-, root, root, 0755)
%{_sysconfdir}/udev/rules.d/*.rules
%{_sysconfdir}/rc.d/init.d/dahdi
%{_sysconfdir}/bash_completion.d/dahdi
%config(noreplace) %{_sysconfdir}/modprobe.d/*
%config(noreplace) %{_sysconfdir}/dahdi/*
%{_sbindir}/*
%{_datadir}/dahdi/*
%{perl_vendorlib}/Dahdi.pm
%{perl_vendorlib}/Dahdi/*
%{_libdir}/*.so.*
%{_libdir}/*.a
%{_mandir}/man8/*
%doc docs/*
%doc linux/drivers/dahdi/xpp/firmwares/OCT6104E-256D-LICENSE.txt

%files devel
%defattr(-, root, root, 0755)
%{_includedir}/dahdi/*.h
%{_libdir}/*.so
/usr/drivers/dahdi/Module.symvers

%files -n kmod-dahdi%{?kxensufix}%{?kmach}
%defattr(-, root, root, 0755)
/lib/modules/%{kernel}/extra/*
/lib/modules/%{kernel}/extra/.kmod-dahdi-%{version}-%{release}
/lib/firmware
/usr/lib/hotplug/firmware

%changelog
* Wed Feb 25 2015 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.10.0.1-3
- Fix conditional prereq for CentOS 7

* Wed Feb  4 2015 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.10.0.1-2
- Add support for new driver allop4xxp

* Mon Jan 12 2015 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.10.0.1-1
- Rebuild for CentOS 7

* Thu Sep 25 2014 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.10.0.1-0
- Update to DAHDI 2.10.0.1
- Add patch for backwards compatibility with udev 095 from CentOS 5.

* Wed Jul 23 2014 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.9.2-0
- Update to DAHDI 2.9.2

* Wed Jul 09 2014 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.9.1.1-0
- Fix package ownership of include files.

* Mon Jun 09 2014 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.9.1.1-0
- Update to DAHDI 2.9.1.1

* Tue Jan 14 2014 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.8.0.1-1
- Add support for new driver allog4c.

* Wed Dec 18 2013 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.8.0.1-0
- Update to DAHDI 2.8.0.1

* Fri Aug  2 2013 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.6.1-6
- Update tej21 driver to latest version, should fix LED blinking issue.

* Thu Feb 28 2013 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.6.1-5
- Update Openvox opvxg4xx patches to chan_extra 2.0.7.
- Add patch to prevent the tor2 driver from grabbing an AlloGSM device (a 
  non-DAHDI device) and causing a kernel panic.
- Patch opvxg4xx driver to prevent collision of macros with Raspberry Pi.
- Fix FC17 compile failure: https://issues.asterisk.org/jira/browse/DAHTOOL-60

* Wed Sep 12 2012 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.6.1-4
- Attempt to handle CentOS 6 via the centos_ver macro just like a Fedora.
- Copy generated Module.symvers to /usr/drivers/dahdi/ for wanpipe and rhino.
- Include OCT6104E-256D.ima from Xorcom. Fixes Elastix bug #1369.

* Tue Sep 04 2012 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.6.1-3
- Update Openvox patches to version 1.3.5

* Fri Jul 06 2012 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.6.1-2
- Apply Openvox patch on wct4xxp so that old firmware can be detected and 
  handled correctly.

* Mon Jun 04 2012 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.6.1-1
- Various fixes for running under Fedora 17.

* Wed May 30 2012 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.6.1-0
- Update to DAHDI 2.6.1
- Add Conflicts so dahdi-devel cannot remain at an older version than dahdi.

* Tue Apr 17 2012 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-11.1
- Unset special linker flag that causes build failures in Fedora 17
- Disable parallel build as DAHDI apparently does not support it
- Add check for HAVE_PCI_SET_MWI before using pci_set_mwi() in voicebus.c.
- Fix zaphfc to correctly compile to a stub when CONFIG_PCI is not defined.

* Mon Apr 16 2012 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-11
- Fix Khomp-Tormenta conflict avoidance patch to check the correct kernel
  structure. Problem discovered and fixed at Khomp headquarters.

* Mon Mar 12 2012 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-10
- Update dahdi to latest 2.4 branch for Fedora compile
- Patch several build failures against Fedora kernel
- Move DAHDI perl libraries to installvendorlib

* Wed Mar 07 2012 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-9
- Fix Requires: dahdi to include exact version of userspace tools
- Add support for ALLO cem4xxp BRI card

* Mon Feb 06 2012 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-8
- Update chan_extra support to 2.0.0.

* Fri Jan 06 2012 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-7
- Update OpenVox patches to support cards with newer firmware.
- Update and reenable SYNWAY support with fixed drivers.

* Tue Dec 06 2011 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-6
- Include support for kernel module weak updates.

* Wed Sep 14 2011 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-5
- SYNWAY support added but disabled (unstable).
- Fix up Wanpipe BRI detection for the TE case

* Tue Aug 09 2011 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-4
- Clean up and reorganize patches around the concept of one manufacturer per 
  patch.
- Drop unused source files from source RPM.
- Update OpenVox drivers to latest OpenVox version, add opvxa24xx driver.

* Fri Aug 05 2011 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-3
- Add missing blacklist for OpenVox G400P driver - else this driver cannot
  coexist with wanpipe (due to it being loaded first) and both get disabled.

* Thu Jul 14 2011 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-2
- Add experimental chan_extra support for OpenVox G400P GSM cards.

* Mon Jun 20 2011 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-1
- Updated ATCOM AX1600P driver to latest version

* Tue Apr 26 2011 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.1.2-0
- Update to 2.4.1.2 
- REMOVED: Drop dahdi-2.4.0-svn9430-return-instead-of-die.patch merged upstream
- REMOVED: Drop dahdi-2.4.0-svn9505-svn9506-bug628.patch merged upstream
- ADDED: Add tonezone information for Kenya. Intended to fix Elastix bug #789.

* Fri Dec 10 2010 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.0-1
- Add patch to prevent the tor2 driver from grabbing a Khomp driver (a 
  non-DAHDI device) and causing a kernel panic.
- Add patch (suggested by Tzafrir Cohen) that combines SVN commits 9505 and 
  9506 to fix unnecessary bad-ioctl messages, and to fix a T1 CAS mode bug.
  Resolves Elastix bug #628.

* Fri Oct 22 2010 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.4.0-0
- Update to 2.4.0
- Conflicts due to ABI change:
  Conflicts: kernel-module-wanpipe%{?kxensufix} <= 3.5.14-0_%{krelver}
  Conflicts: kernel-module-rhino <= 0.99.3-2.beta2_%{krelver}
  Conflicts: asterisk <= 1.6.2.13-0
- REMOVED: Drop dahdi-bri_dchan-2.2.patch which is apparently not needed, 
  according to Elastix bug #398. Now done correctly with Conflicts: to prevent
  loading along with incompatible rhino/wanpipe.
- REMOVED: Drop dahdi-2.3.0.1-xpp_fxloader-svn8580-svn8589-delayed-load.diff,
  patch merged upstream.
- ADDED: Requires: which . Should fix Elastix bug #441.
- CHANGED: Update oslec patch to set the default echo-canceller to oslec. Part 
  of fix for Elastix bug #174.
- CHANGED: Ship empty /etc/dahdi/modules file and populate it at post-install
  time with 'dahdi_genconf modules'. Part of fix for Elastix bug #174.
- CHANGED: Updated ap400, opvxa1200, opvxd115, wcopenpci, ystdm16xx, ystdm8xx,
  zaphfc to latest versions, to fix ABI breakage.
- CHANGED: Patched ax1600p to fix ABI breakage. NEEDS TEST.
- CHANGED: Merged patch for DAHDI SVN revision 9430 by request from Tzafrir.
- CHANGED: Patch linux/Makefile to install version.h to /usr/include/dahdi/ as
  the rhino build process depends on its presence.

* Thu Jul 29 2010 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.3.0.1-3
- ADDED: Re-add dahdi-bri_dchan-2.2.patch - removal is an ABI change and it
  causes crashes in wanpipe/rhino unless recompiled. Will schedule proper
  removal after Elastix-2.0 stable launch.

* Wed Jul 28 2010 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.3.0.1-2
- FIXED: Added assignment of span.owner to several drivers maintained outside of
  vanilla dahdi-2.3.0.1. Should fix Elastix bug #408.
- CHANGED: Sync zaphfc from http://git.tzafrir.org.il/git/dahdi-extra.
- REMOVED: Drop dahdi-bri_dchan-2.2.patch which is apparently not needed, 
  according to Elastix bug #398.

* Thu Jul 01 2010 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.3.0.1-1
- FIXED: merge SVN commits 8580 and 8589 from dahdi trunk to fix problems with
  Astribank firmware loading. Should fix Elastix bug #369.
- FIXED: manually install xpp.conf to /etc/dahdi. Should fix Elastix bug #371
- Mark several files as documentation.

* Thu May 27 2010 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.3.0.1-0
- Update to 2.3.0.1

* Mon May 17 2010 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.3.0-1
- Blacklist modules hisax and hfc4s8s_l1 that are part of stock CentOS
  kernel, and conflict with DAHDI drivers.

* Fri Apr 16 2010 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.3.0-0
- Update to 2.3.0
- Drop redfone_ethmf_driver_for_dahdi.patch merged upstream
- Drop dahdi-2.2.0.2-sync-to-rsp-003-dahdi_timing.diff merged upstream
- Fix AP400 driver for dahdi_span struct change: dahdi-2.3.0-ap400-rename-errcount.patch

* Thu Apr 01 2010 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.2.1.1-0
- Update to 2.2.1.1
- Add patch to unload oslec along with dahdi on dahdi unload. Suggested by
  tzafrir. Should fix Elastix bug #258.
- Update OpenVox drivers to include opvxd115
- Re-sync to asterisk-es-rsp at March 31 for zaphfc and wcb4xxp drivers

* Sat Feb 27 2010 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.2.1-0
- Update to 2.2.1
- Remove no-longer-needed patching of Makefiles via perl
- Fix dangling reference to Zaptel in -devel package description
- Remove separate FPGA_1161.hex from SRPMS, merged upstream
- Remove dahdi-2.2.0.1-backport-r6785.patch merged upstream
- Remove dahdi-2.2.0.2-bug15647-svn6933-do_not_lockup_with_dahdi_dummy.patch
  merged upstream

* Tue Dec 22 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.2.0.2-7
- Add support for wcopenpci cards (conflicts with mISDN-modules netjetpci)

* Mon Sep 14 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.2.0.2-6
- Apply firmware update FPGA_1161.hex to fix Elastix bug #154.

* Fri Aug 28 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.2.0.2-5
- Undo split-out of BRI card support for Elastix 2.0.

* Thu Aug 06 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.2.0.2-4
- Apply patch from dahdi SVN trunk at revision 6933 to fix issue when dahdi_dummy
  is loaded in which a change of system time (by ntpd for example) could lock
  up the system. Should fix Digium bug #15647, Elastix bug #148.

* Wed Aug 05 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.2.0.2-3
- Do not remove zaphfc and wcb4xxp-extra from /etc/dahdi/modules on %postun
  when upgrading.
- Fix unexpected request of echo canceller symbols on ap400.

* Tue Aug 04 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.2.0.2-2
- Add expected firmware copy for ap400 and re-enable compile.
- Sync patches for dahdi BRI support to the ones available from asterisk-es-rsp.
- Enable CONFIG_DAHDI_CORE_TIMER from patch from asterisk-es-rsp. 
- Split out additional BRI cards into wcb4xxp-extra which is a copy of wcb4xxp.

* Thu Jul 30 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.2.0.2-1
- Split out zaphfc driver into kernel-module-dahdi-bri and place it in
  the elastix-extras repository. People who wish to use zaphfc should
  install it and remove/disable mISDN from their configurations.
- Re-add ap400 for Aligera E1 cards with hardware-echo support disabled,
  while awaiting for a proper fix from Aligera.

* Fri Jul 24 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.2.0.2-0
- Update to 2.2.0.2

* Thu Jul 23 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.2.0.1-0
- Update to 2.2.0.1
- Drop USB_FW.hex as file in tarball is more recent.
- Drop FPGA_1141.hex, FPGA_1151.hex, FPGA_FXS.hex, merged upstream
- Drop xpp_backport_linux_2104.diff, merged upstream
- Drop xpp_backport_tools_2102_2.diff, merged upstream
- Drop no_dahdi_dummy_rtc-3.patch, merged upstream
- Drop dahdi-ignore-nonnumeric-spans.patch, merged upstream
- Drop dahdi-recognize-rhino-t1.patch, merged upstream
- Make kernel-module-dahdi* depend on dahdi, rather than the other way around, 
  in order to enable install of dahdi without kernel modules (Elastix 
  issue #84).
- Obsolete kernel-module-dahdi-devel since dahdi now copies kernel files to
  /usr/include/dahdi .
- Copy Module.symvers as a kernel devel file to silence wanpipe build warning.
- Rename supplied genconf_parameters as genconf_parameters.sample since elastix
  package supplies its own copy.
- Added dahdi-bri_dchan-2.2.patch for BRI driver support (issue #70).
- Temporarily drop support for Aligera E1 cards, due to echo canceller interface
  incompatibility.

* Fri Jul 10 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-23
- Merge zaphfc support patches by José Antonio Déniz Fabelo (odicha)
- Add BRI cards and other extra supported cards to PCI.pm for dahdi_hardware.

* Mon Jul 06 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-22
- Fix AX-1600P driver to report a span and a channel name without spaces, 
  otherwise dahdi utilities trip up on this span ("Unrecognized garbage XXX in ATCOM")
- Fix dahdi tools to recognize the need to probe for FXS/FXO for ATCOM as it
  is done in the case of WCTDM.

* Fri Jul 03 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-21
- Backport commit 6875 on dahdi-base.c to fix refcounting of echo cancellers.

* Fri Jun 26 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-20
- Add AX-1600P support again, this time with just one PCI ID.
- Revert copying of Module.symvers. This file is specific to kernel version, and
  therefore cannot be shared by kernel-module-dahdi-devel without a specific
  kernel version.

* Fri Jun 19 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-19
- Revert patch for AX-1600P support for ATCOM. It breaks functionality for other
  cards that get managed by the same driver. This patch needs to be reviewed
  quite a bit more to isolate the card support. Patch still in source RPM, but
  not applied

* Tue Jun 16 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-18
- Copy over Module.symvers on %%install, checked by wanpipe.

* Tue Jun 09 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-17
- Do not overwrite module configuration files on update, since these are modified
  by rhino. Instead check whether module is present and add it if not.

* Tue Jun 09 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-16.1
- On closer look, ax1600p is actually an extension on wctdm, so patch wctdm.c 
  instead.

* Tue Jun 09 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-16
- Support for AX-1600P FXS/FXO cards by ATCOM.

* Fri May 15 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-15
- Support for Aligera E1 Cards (http://www.aligera.com.br/produtos_open.php?cod=14)
- Instruct dahdi tools to recognize the Aligera cards a la rhino/wanpipe

* Thu May 14 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-14
- A similar patch to the one required by rxt1 is required for Sangoma cards,
  in order not to trip up dahdi_genconf (dahdi-recognize-sangoma-t1.patch).

* Tue May 12 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-13
- If the rhino modules rxt1 (and possibly r1t1) are loaded, their corresponding
  /proc/dahdi/? files trip up dahdi_genconf and hardware_detector, due to 
  unrecognized card/channel descriptions. Fixed by dahdi-recognize-rhino-t1.patch .

* Mon May 11 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-12
- Revert a bit of the update patch on dahdi tools. Fixes issue #92.

* Wed May 06 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-11
- Ignore non-numeric filenames when processing /proc/dahdi/*. Suggested by Tzafir.

* Mon Apr 27 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-10
- Add the modules opvxa1200 ystdm8xx ystdm16xx dahdi_dynamic_eth dahdi_dynamic_ethmf
  to /etc/dahdi/modules and /etc/modprobe.d/dahdi.blacklist in order to ensure
  consistent module loading ordering as is done with default dahdi drivers.

* Thu Apr 16 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-9
- Updated driver opvxa1200.c
  - Solving the g0 problem when run: dial(daidi/g0/XXXXXXX), previously, 
    the system can not find an active channel in g0.  Now, it can be done!
  - Improved FXO battery detection. system will able to check the dahdi 
    or zaptel hook_state for FXO.  run cat /proc/dahdi/1 will see the FXO 
    line connection activity.

* Wed Apr 15 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-8
- Patch to fix Digium issue #13930, Elastix issues #67, #68 - kernel panic on
  paravirtualized Xen startup on dahdi_dummy.
- Patch for support for OpenVox D110PG.

* Tue Mar 31 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-7
- Update ystdm8xx to latest vendor-supplied driver, add ystdm16xx support.
- Again, ystdm8xx was included but never built. Again, MODULES_EXTRA changed
  to include it. Fixes issue #55.

* Thu Mar 26 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-6
- Add MODULES_EXTRA parameter to enable build of opvxa1200, which was included
  but never build at all. Fixes issue #43.

* Wed Mar 18 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-5
- Apply xpp_backport_linux_2104.diff and xpp_backport_tools_2102.diff
- Replace firmware drivers for xpp

* Fri Mar 13 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-4
- Remove zaptel to dahdi migration script - approach is broken in fresh install
  of dahdi RPM. Fold migration logic into specfile instead. Fixes issue #23.
- Create %{buildroot}/etc/udev/rules.d before installing kernel modules so
  that DYNFS installing of udev rules is properly triggered. This makes 
  separate dahdi.rules obsolete, so it is removed. Fixes issue #20.
- Remove a few unneeded files

* Thu Mar 12 2009 Bruno Macias <bmacias@palosanto.com> - 2.1.0.4-3
- Fix placement of execution point for zaptel to dahdi migration script

* Tue Mar 10 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-2
- Small cleanup of specfile
- Comment out OSLEC references which are not needed anymore
- Kernel-devel files for dahdi are the same regardless of kernel version so
  they depend only on dahdi version.
- Translate comments on specfile to English.

* Wed Mar 04 2009 Bruno Macias <bmacias@palosanto.com> - 2.1.0.4-1
- Obsoletes: zaptel, zaptel-devel, kernel-module-zaptel, kernel-module-zaptel-xen
- Source3: migration zaptel to dahdi config

* Mon Mar 02 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.4-0
- Update dahdi to 2.1.0.4

* Fri Feb 27 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.3-8
- Add dahdi.rules to fix permissions for asterisk access.

* Thu Feb 26 2009 Bruno Macias <bmacias@palosanto.com> - 2.1.0.3-7
- Support redfone ethmf driver for dahdi, file included:
   - patch13: redfone_ethmf_driver_for_dahdi.patch

* Wed Feb 04 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.3-5.1
- Add Makefile from sources to please wanpipe build

* Tue Feb 03 2009 Alex Villacis Lasso <a_villacis@palosanto.com> - 2.1.0.3-5
- Fix spec for building in 64-bits
- Add new package kernel-module-dahdi-devel for files needed to build kernel-rhino
- Add copy of oslec from linux staging
- Obsolete oslec packages, dahdi includes internal copy of oslec

* Mon Nov 10 2008 Bruno Macias <bmacias@palosanto.com> - 1.4.12.1-2
- Update the kernel to 2.6.18-92.1.17.el5.

* Wed Oct 29 2008 Bruno Macias <bmacias@palosanto.com> - 1.4.12.1-1
- Update zaptel 1.4.12.1, version alpha
- Correction zap channels "On hook"
- Added defattr /lib/firmware and /usr/lib/hotplug/firmware.

* Thu Sep 18 2008 Bruno Macias <bmacias@palosanto.com> - 1.4.11-6
- New patch 12, this is for added new option -x (created file configs, zaptel.conf and zapata.conf).
  This action have relation with script hardware_detector (in rpm elastix)

* Mon Sep 01 2008 Bruno Macias <bmacias@palosanto.com> - 1.4.11-5
- Increase release

* Mon Jun 09 2008 Tzafrir Cohen <tzafrir.cohen@xorcom.com> - 1.4.10.1.xpp.r5716-3 
- Added bri_dchan patch to build our BRI module as well.

* Wed May 21 2008 Edgar Landivar <elandivar@palosanto.com>     - 1.4.10.1-2
- Updating to the 1.4.10.1 version
- Including patch for rhino cards being detected in the genzaptelconf command

* Tue Mar 25 2008 Bruno Macias <bmacias@palosanto.com>     - 1.4.9.2.xxp.r5517-3
- Comments Provides. Fixed bug in yum update kernel-module-zaptel and kernel-module-zaptel-xen.

* Tue Mar 18 2008 Edgar Landivar <elandivar@palosanto.com> - 1.4.9.2.xpp.r5517-2
- Updating the OSLEC patch

* Wed Mar  5 2008 Tzafrir Cohen <tzafrir.cohen@xorcom.com> - 1.4.9.2.xpp.r5517-1
- 1.4.9.2 with some even newer xpp code.
- Fixing the OSLEC patch for 1.4.8.
- zaptel_xpp_sleep_workaround.diff: Fix loading right after resetting
  the Astribank firmware (e.g: on XR3000 startup).

* Sat Feb 21 2008 Edgar Landivar <elandivar@palosanto.com> 1.4.8-1
- Updated to zaptel 1.4.8

* Sat Jan 26 2008 Edgar Landivar <elandivar@palosanto.com> 1.4.7.1-1
- Updated to zaptel 1.4.7.1

* Wed Dec 18 2007 Edgar Landivar <elandivar@palosanto.com> 1.4.6-3
- Including patch to fix a bug in astribank devices http://svn.digium.com/view/zaptel?view=rev&revision=3229
  Reported by Tzafrir

* Wed Dec 12 2007 Edgar Landivar <elandivar@palosanto.com> 1.4.6-2
- Installing some missed modules: opvxa1200 zma8xx ztd-ethmf
- Modifying the genzaptelconf command to support the ystdm8xx zma8xx ztd-ethmf drivers

* Mon Nov 26 2007 Tzafrir Cohen <tzafrir.cohen@xorcom.com> 1.4.6-1
- Remove zaptel-init.patch: the defualt is set in the sysconfig file.
- openvox, ystdm8xx and zma8xx patches should not edit makefile:
  set MODULES_EXTRA instead.
- Set ECHO_CAN_NAME instead of patching Makefile.kernel26 .
- Remove hotplug files: we're not centos 4 anymore.
- Remove ifup-hdlc: At least until someone actually uses it (it doesn't
  work).

* Tue Nov 20 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-31
- Minor change in the redfone patch applied

* Tue Nov 20 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-30
- Redfone patch applied

* Thu Oct 23 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-28
- OpenVox patch applied to support A800 and A1200 cards.
- Now kernel-module-oslec is required

* Thu Oct 22 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-26
- Touching fxotune file

* Thu Oct 20 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-25
- Better XEN support when building the RPM.
- Fixed minor typo error in the postun section related with the depmod invocation.

* Thu Oct 18 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-23
- Added logic to check if there is a previous genzaptelconf version.
- Octasic support removed. OSLEC is the official Elastix echo canceller now.

* Tue Oct 11 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-21
- Some changes regarding Octasic support. Some files will belong to a new
  octasic package. Just the octasic modules remain in the zaptel package.

* Tue Oct  9 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-20
- Symbolic Link from /usr/local/sbin/genzaptelconf to /usr/sbin/genzaptelconf
  to maintain compatibility with the older genzaptelconf location in Elastix.

* Fri Sep 14 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-12
- Octasic echo canceller support added.
- OSLEC temporally removed because it does not work against this zaptel version.

* Tue Sep 11 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-6
- Zapmicro ZMA800 patch added.

* Tue Sep 11 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-4
- OSLEC echo canceller support added.

* Wed Sep 5 2007 Edgar Landivar <elandivar@palosanto.com>1.4.5.1-2
- Removing the libusb-devel requirement until the next version, when that 
  package will be included in the rpm builder machine.

* Fri Aug 24 2007 Tzafrir Cohen <tzafrir.cohen@xorcom.com> 1.4.5.1-1
- New upstrem release - fixes Makefile typo.
- Removing makefile typo.
- Remove b410p mISDN drivers: they belong in an misdn package.

* Mon Jun 11 2007 Edwin Boza <www.palosanto.com>
- Add yeastar module to /etc/sysconfig/zaptel
- Initialize service zaptel on level 2345

* Sat Mar 17 2007 Joel Barrios <http://joel-barrios.blogspot.com/>
- Update to 1.4.0.

* Sun Mar 04 2007 Joel Barrios <http://joel-barrios.blogspot.com/>
- Update to 1.2.15

* Sun Dec 17 2006 Joel Barrios <http://linuxparatodos.net/>
- Update to 1.2.12

* Fri Nov 24 2006 Matthias Saou <http://freshrpms.net/> 1.2.11-1
- Update to 1.2.11.

* Thu Sep  7 2006 Matthias Saou <http://freshrpms.net/> 1.2.8-1
- Update to 1.2.8.

* Thu May  4 2006 Matthias Saou <http://freshrpms.net/> 1.2.5-1
- Update to 1.2.5.

* Wed Mar 15 2006 Matthias Saou <http://freshrpms.net/> 1.2.4-1
- Rebuild fails on RHEL4 up U3 (included), because of a typo :
  https://bugzilla.redhat.com/180568

* Tue Mar  7 2006 Matthias Saou <http://freshrpms.net/> 1.2.4-1
- Update to 1.2.4.

* Tue Jan 31 2006 Matthias Saou <http://freshrpms.net/> 1.2.3-1
- Update to 1.2.3.

* Fri Jan 27 2006 Matthias Saou <http://freshrpms.net/> 1.2.2-1
- Update to 1.2.2.

* Fri Nov 25 2005 Matthias Saou <http://freshrpms.net/> 1.2.0-1
- Update to 1.2.0.
- No longer patch the Makefile, horray!
- Kernel modules are now in "extra" and no longer in "misc".
- Split off devel sub-package.

* Thu Sep 15 2005 Matthias Saou <http://freshrpms.net/> 1.0.9.2-1
- Update to 1.0.9.2.
- Update makefile patch to add ztdummy to the modules.
- Fix kernel-smp-devel requirement for smp modules rebuild.

* Tue Aug 23 2005 Matthias Saou <http://freshrpms.net/> 1.0.9.1-0
- Update to 1.0.9.1.
- Remove "devices" from install with the Makefile patch.
- Replace /usr/lib in Makefile with %%{_libdir} to fix 64bit lib location.

* Tue Apr  5 2005 Matthias Saou <http://freshrpms.net/> 1.0.7-0
- Update to 1.0.7.
- This spec still doesn't build with mach (sub-package release tag bug).

* Tue Mar  8 2005 Matthias Saou <http://freshrpms.net/> 1.0.6-0
- Update to 1.0.6.
- Change /dev/MAKEDEV calls to /sbin/MAKEDEV for FC3.
- Rework and re-enable the kernel modules, only through kernel-devel, though.

* Wed Feb  2 2005 Matthias Saou <http://freshrpms.net/> 1.0.4-0
- Update to 1.0.4.
- Updated makefile patch.
- Keep "/dev" from being owned by the package.

* Mon Oct 18 2004 Matthias Saou <http://freshrpms.net/> 1.0.1-0
- Update to 1.0.1.

* Mon Aug 30 2004 Matthias Saou <http://freshrpms.net/> 1.0-0.RC2.0
- Update to 1.0-RC2.
- Disable kernel module building for now, we don't use any.

* Mon Jul 26 2004 Matthias Saou <http://freshrpms.net/> 1.0-0.RC1.1
- Update to 1.0-RC1.
- Major Makefile patch updates, spec updates to match.

* Mon Nov 17 2003 Matthias Saou <http://freshrpms.net/>
- Uncomment the ztdummy module to have it built.

* Wed Nov  5 2003 Matthias Saou <http://freshrpms.net/>
- Initial RPM release.

